"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fix = fix;
const config_config_writer_1 = require("@pnpm/config.config-writer");
const difference_1 = __importDefault(require("ramda/src/difference"));
async function fix(auditReport, opts) {
    const vulnOverrides = createOverrides(Object.values(auditReport.advisories), opts.auditConfig?.ignoreCves);
    if (Object.values(vulnOverrides).length === 0)
        return vulnOverrides;
    await (0, config_config_writer_1.writeSettings)({
        updatedSettings: {
            overrides: {
                ...opts.overrides,
                ...vulnOverrides,
            },
        },
        rootProjectManifest: opts.rootProjectManifest,
        rootProjectManifestDir: opts.rootProjectManifestDir,
        workspaceDir: opts.workspaceDir ?? opts.rootProjectManifestDir,
    });
    return vulnOverrides;
}
function createOverrides(advisories, ignoreCves) {
    if (ignoreCves) {
        advisories = advisories.filter(({ cves }) => (0, difference_1.default)(cves, ignoreCves).length > 0);
    }
    return Object.fromEntries(advisories
        .filter(({ vulnerable_versions, patched_versions }) => vulnerable_versions !== '>=0.0.0' && patched_versions !== '<0.0.0') // eslint-disable-line
        .map((advisory) => [
        `${advisory.module_name}@${advisory.vulnerable_versions}`,
        advisory.patched_versions,
    ]));
}
//# sourceMappingURL=fix.js.map